@@ -40,8 +40,10 @@ sub _given_when {
                 }
             }
 
-            if ( $found->{run} ) { 
-                my @new = $found->{run}->( $self, $find, $set, );
+            if ( my $run = $found->{run} ) { 
+                my @new = ref $run =~ m/^CODE|Type::Tiny$/
+                    ? $found->{run}->( $self, $find, $set, ) 
+                    : $self->$run($find, $set);
                 $set = scalar @new > 1 ? \@new : shift @new;
             }
 
@@ -57,8 +59,8 @@ sub _given_when {
 sub _variant_last_value {
     my ($self, $attr, $value, $set) = @_;
 
-    $self->variant_last_value->{$attr}->{$value} or return undef;
-    return _ref_the_same($self->variant_last_value->{$attr}->{$value}, $set);
+    my $stored = $self->variant_last_value->{$attr}->{$value} or return undef;
+    return _ref_the_same($stored, $set);
 }
 
 sub _ref_the_same {
@@ -104,14 +106,11 @@ sub _find_from_given {
 
     my $ref_given = ref $given;
     if ( $ref_given eq 'Type::Tiny' ) {
-        my $display_name = $given->display_name;
         $set = $given->($set);
-        $display_name eq 'Object' and return ref $set;
-        return $set;
+        return $given->display_name eq 'Object' ? ref $set : $set;
     }
     elsif ( $ref_given eq 'CODE' ) {
-        my $val = $given->( $self, $set );
-        return $val;
+        return $given->( $self, $set );
     }
 
     return $set;
